@@ -169,7 +169,7 @@ class CustomLSTM2(nn.Module):
               #print(i_t.shape, f_t.shape, g_t.shape, o_t.shape, c1_t.shape)
               c_t = f_t * c_t.T + i_t * g_t
               h_t = o_t * torch.tanh(c_t)
-              l_t = h_t
+              l_t = h_t.T
               if len(hnew)<(i+1):
                 hnew.append(h_t.T.reshape(b,HS))
                 cnew.append(c_t.T.reshape(b,HS))
